import * as CHARACTER from "./character.mjs"
import * as WEAPON from "./weapon.mjs"
import * as ARMOR from "./armor.mjs"
import * as SPELL from "./spell.mjs"
import * as SKILL from "./skill.mjs"
import * as EQUIPMENT from "./equipment.mjs"

export const SYSTEM_ID = "fvtt-lethal-fantasy"
export const DEV_MODE = false

export const DICE_VALUE = Object.freeze({
  D4: "d4",
  D6: "d6",
  D8: "d8",
  D10: "d10",
  D12: "d12",
})

export const DICE_VALUES = ["0", "d4", "d6", "d8", "d10", "d12"]

export const ROLL_TYPE = Object.freeze({
  SAVE: "save",
  RESOURCE: "resource",
  DAMAGE: "damage",
  ATTACK: "attack",
})

export const MONEY = {
  tinbit: {
    id: "tinbit",
    abbrev: "tb",
    label: "LETHALFANTASY.Money.Tinbits",
    valuetb: 1
  },
  copper: {
    id: "copper",
    abbrev: "cp",
    label: "LETHALFANTASY.Money.Coppers",
    valuetb: 10
  },
  silver: {
    id: "silver",
    abbrev: "sp",
    label: "LETHALFANTASY.Money.Silvers",
    valuetb: 100
  },
  gold: {
    id: "gold",
    abbrev: "gp",
    label: "LETHALFANTASY.Money.Golds",
    valuetb: 1000
  },
  platinum: {
    id: "platinum",
    abbrev: "pp",
    label: "LETHALFANTASY.Money.Platinums",
    valuetb: 10000
  }
}

export const ASCII = `
······················································································································
:                                                                                                                    :
:@@@      @@@@@@@@ @@@@@@@ @@@  @@@  @@@@@@  @@@         @@@@@@@@  @@@@@@  @@@  @@@ @@@@@@@  @@@@@@   @@@@@@ @@@ @@@ :
:@@!      @@!        @!!   @@!  @@@ @@!  @@@ @@!         @@!      @@!  @@@ @@!@!@@@   @!!   @@!  @@@ !@@     @@! !@@ :
:@!!      @!!!:!     @!!   @!@!@!@! @!@!@!@! @!!         @!!!:!   @!@!@!@! @!@@!!@!   @!!   @!@!@!@!  !@@!!   !@!@!  :
:!!:      !!:        !!:   !!:  !!! !!:  !!! !!:         !!:      !!:  !!! !!:  !!!   !!:   !!:  !!!     !:!   !!:   :
:: ::.: : : :: ::     :     :   : :  :   : : : ::.: :     :        :   : : ::    :     :     :   : : ::.: :    .:    :
:                                                                                                                    :
······················································································································
`

/**
 * Include all constant definitions within the SYSTEM global export
 * @type {Object}
 */
export const SYSTEM = {
  id: SYSTEM_ID,
  CHARACTERISTICS: CHARACTER.CHARACTERISTICS,
  RESOURCES: CHARACTER.RESOURCES,
  SAVES: CHARACTER.SAVES,
  SKILL_CATEGORY: SKILL.CATEGORY,
  WEAPON_CATEGORY: WEAPON.CATEGORY,
  WEAPON_DAMAGE: WEAPON.DAMAGE,
  ARMOR_TYPE: ARMOR.TYPE,
  EQUIPMENT_CATEGORY: EQUIPMENT.CATEGORY,
  SPELL_RANGE: SPELL.RANGE,
  WEAPON_TYPE: WEAPON.WEAPON_TYPE,
  MONEY,
  ASCII,
  ROLL_TYPE,
  DEV_MODE,
}
